==> dl.php?src=linea21_1_0.zip: linea21/workshop/mod_cal.php <==
<?php
include_once("../lib/select_box.php");
if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
//////////// Check Inclusion de pages //////////// 
if (!function_exists('AuthenthificationProcess')){ 
include_once("../lib/lib_common.php");
ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////  
if (WorkshopAuth_id(GetSessionElement('id'), $sql_object, $id)<>true && !IsSuperAdmin())
ReloadIndex('admin');  
////////////


$link_add_cal = $rub_link . "&amp;todo=add_cal&amp;id=";
$link_det = $rub_link . "&amp;todo=det&amp;id=";

if(isset($_POST['task_id']))	$task_id=$_POST['task_id'];
if(isset($_GET['task_id']))	$task_id=$_GET['task_id'];

$calendar_object= new calendar;

//$result_task=$calendar_object->GetOneTask($task_id, $sql_object);
$req_task=SQL_getOneTask($task_id);
$result_task = $sql_object -> DBSelect($req_task);

$date_value=$result_task[0]['date_t'];
$date_value=explode("-", $date_value);
$form_day = $date_value[0];
$form_month = $date_value[1];
$form_year = $date_value[2];
$form_task=formatText($result_task[0]['workcal_task'], '2FIELD');
$display_title_task=formatText($result_task[0]['workcal_task'], '2FIELD');
$form_task_details=formatText($result_task[0]['workcal_task_details'], '2FIELD');

$req_det_workshop= SQL_getoneCompleteWorkshop($id);
$result_workshop=$sql_object->DBSelect($req_det_workshop);
$workshop_denomination=formatText($result_workshop[0]['workshop_denomination'], '2FIELD');
$link_cancel=$rub_link."&amp;todo=list_cal&amp;id=".$id;
//$workshop_object= new workshop;

if(isset($_POST['enregistrer'])) {

	$data_table=unserialize(urldecode($_POST['data_table']));
	$result=$calendar_object->ModifyTask($task_id, $data_table, $sql_object);
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&id=".$id;
	if($result==1) header("Location: ".$link_confirm);
	else  system_error();
}


if(isset($_POST['valider'])) {

	$day =$_POST['day'];
	$month =$_POST['month'];
	$year =$_POST['year'];
	
//traitement de la date
	$date_timestamp=$year."-".$month."-".$day;
   $date_timestamp_display=$day."-".$month."-".$year;
  	$table[0] = $date_timestamp;
  	$table[1] = $_POST['task'];
  	$table[2] = $_POST['task_details'];
  	$table[3] = $_POST['id'];

	$integrity=$calendar_object->CheckDataIntegrity($table, $sql_object);
	
	if(is_string($integrity)) {
		$text_format='2FIELD';
	} else {
		$text_format='2HTML';
		//$table[6]=$integrity;
		}
	$form_task=formatText($_POST['task'], $text_format);
	$form_task_details=formatText($_POST['task_details'], $text_format);
	$form_day =$_POST['day'];
	$form_month =$_POST['month'];
	$form_year =$_POST['year'];
	 $table=urlencode(serialize($table));
}
include_once("quickicons.php");
$navtitle=$GLOBALS['lang']['workshop']['mod_cal']." : ".$display_title_task;
?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home'] ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu']['workshop']?></a>
		</li>
		<li>
			<span><? echo formatnavTitle($navtitle); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
if(!isset($integrity) || is_string($integrity)) {
?>
<div class="contentcontainer">
		<?php
		include_once($dir."/menurub.php");
?>
		<div id="content">
			<?php
			if(isset($integrity) && is_string($integrity)) display_errors($integrity);
			?>
<?php afflinkbar($todo,$id, $lang); ?>
			<h2>
			<? echo formatTitleh2($GLOBALS['lang']['workshop']['name']." : ".$workshop_denomination); ?>
			</h2>
			<form id="addtask" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
				<p>
				<label for="task"><? echo $GLOBALS['lang']['workshop']['task']; ?> * : </label>
				<input name="task" type="text" class="textfield" id="task" maxlength="255" value="<?php echo $form_task; ?>" />
				</p>
				<p>
				<label for="task_details"><? echo $GLOBALS['lang']['workshop']['task_details']; ?> * : </label>
				<textarea id="task_details" name="task_details" <?php echo AREA_SETTINGS; ?> class="largetextfield" ><?php echo $form_task_details; ?></textarea>
				</p>
				<p>
				<? echo $GLOBALS['lang']['workshop']['date']; ?> :
				</p>
				<div class="datediv">
				<p class="date">
				<label for="day" class="labeldate" ><?php echo $GLOBALS['lang']['workshop']['day'] ?> * :</label>
                <?php $day=select_date($form_day, "day", "D");
				echo $day; ?>
				</p>
				<p class="date">
				<label for="month" class="labeldate" ><?php echo $GLOBALS['lang']['workshop']['month'] ?> * :</label>
				<?php $month=select_date($form_month, "month", "M");
				echo $month; ?>
				</p>
				<p class="date">
				<label for="year" class="labeldate" ><?php echo $GLOBALS['lang']['workshop']['year'] ?> * :</label>
				<?php $year=select_date($form_year, "year", "Y"); 
				echo $year;
				?>
				</p>
				<br class="brendstep" />
				</div>
				<div>
				<input name="task_id" type="hidden" value="<?php echo $task_id; ?>" id="task_id" />
				<input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
				<? echo cancel_button($link_cancel); ?>
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid'] ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
<?php include_once($dir."/help.php"); ?>
</div>
<?php
// Rcapitulatif
} else	{

if(empty($form_task)) $display_form_task=$GLOBALS['lang']['workshop']['recap_nc'];
else $display_form_task=formatText($form_task, $text_format);

if(empty($form_task_details)) $display_form_task_details=$GLOBALS['lang']['workshop']['recap_nc'];
else $display_form_task_details=formatText($form_task_details, $text_format);

$date_timestamp_display;
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
<?php afflinkbar($todo,$id, $lang); ?>
			<h2><? echo $GLOBALS['lang']['recap']['title'] ?></h2>
			<?php
			echo "<dl class=\"dl3\">\n";
			echo "<dt>".$GLOBALS['lang']['workshop']['task']."</dt>\n";
			echo "<dd>". $display_form_task."</dd>\n";
			echo "<dt>". $GLOBALS['lang']['workshop']['task_details']. "</dt>\n";
			echo "<dd>".$display_form_task_details."</dd>\n";
			echo "<dt>".$GLOBALS['lang']['workshop']['date']." :</dt>\n";
			echo "<dd>".$date_timestamp_display."</dd>\n";
			echo "</dl>\n";
			?>
			<form id="addtask" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
				<div>
				<input name="task_id" type="hidden" value="<?php echo $task_id; ?>" id="id" />
				<input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<? echo cancel_button($link_cancel); ?>
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="data_table" type="hidden" value="<?php echo $table; ?>" id="data_table" />
				<input name="retour" type="button" value="<? echo $GLOBALS['lang']['btn']['preview'] ?>" class="button" id="retour" onclick="history.go(-1);" />
				<input name="enregistrer" type="submit" value="<? echo $GLOBALS['lang']['btn']['save'] ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
	<?php include_once($dir."/help.php"); ?>
</div>
<?php
}
?>

==> dl.php?src=linea21_1_1.zip: linea21/workshop/mod_cal.php <==
<?php
include_once("../lib/select_box.php");
if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
//////////// Check Inclusion de pages //////////// 
if (!function_exists('AuthenthificationProcess')){ 
include_once("../lib/lib_common.php");
ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////  
if (WorkshopAuth_id(GetSessionElement('id'), $sql_object, $id)<>true && !IsSuperAdmin())
ReloadIndex('admin');  
////////////


$link_add_cal = $rub_link . "&amp;todo=add_cal&amp;id=";
$link_det = $rub_link . "&amp;todo=det&amp;id=";

if(isset($_POST['task_id']))	$task_id=$_POST['task_id'];
if(isset($_GET['task_id']))	$task_id=$_GET['task_id'];

$calendar_object= new calendar;

//$result_task=$calendar_object->GetOneTask($task_id, $sql_object);
$req_task=SQL_getOneTask($task_id);
$result_task = $sql_object -> DBSelect($req_task);

$date_value=$result_task[0]['date_t'];
$date_value=explode("-", $date_value);
$form_day = $date_value[0];
$form_month = $date_value[1];
$form_year = $date_value[2];
$form_task=formatText($result_task[0]['workcal_task'], '2FIELD');
$display_title_task=formatText($result_task[0]['workcal_task'], '2FIELD');
$form_task_details=formatText($result_task[0]['workcal_task_details'], '2FIELD');

$req_det_workshop= SQL_getoneCompleteWorkshop($id);
$result_workshop=$sql_object->DBSelect($req_det_workshop);
$workshop_denomination=formatText($result_workshop[0]['workshop_denomination'], '2FIELD');
$link_cancel=$rub_link."&amp;todo=list_cal&amp;id=".$id;
//$workshop_object= new workshop;

if(isset($_POST['enregistrer'])) {

	$data_table=unserialize(urldecode($_POST['data_table']));
	$result=$calendar_object->ModifyTask($task_id, $data_table, $sql_object);
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&id=".$id;
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}


if(isset($_POST['valider'])) {

	$day =$_POST['day'];
	$month =$_POST['month'];
	$year =$_POST['year'];
	
//traitement de la date
	$date_timestamp=$year."-".$month."-".$day;
   $date_timestamp_display=$day."-".$month."-".$year;
  	$table[0] = $date_timestamp;
  	$table[1] = $_POST['task'];
  	$table[2] = $_POST['task_details'];
  	$table[3] = $_POST['id'];

	$integrity=$calendar_object->CheckDataIntegrity($table, $sql_object);
	
	if(is_string($integrity)) {
		$text_format='2FIELD';
	} else {
		$text_format='2HTML';
		//$table[6]=$integrity;
		}
	$form_task=formatText($_POST['task'], $text_format);
	$form_task_details=formatText($_POST['task_details'], $text_format);
	$form_day =$_POST['day'];
	$form_month =$_POST['month'];
	$form_year =$_POST['year'];
	 $table=urlencode(serialize($table));
}
include_once("quickicons.php");
$navtitle=$GLOBALS['lang']['workshop']['mod_cal']." : ".$display_title_task;
?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home'] ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu']['workshop']?></a>
		</li>
		<li>
			<span><? echo formatnavTitle($navtitle); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
if(!isset($integrity) || is_string($integrity)) {
?>
<div class="contentcontainer">
		<?php
		include_once($dir."/menurub.php");
?>
		<div id="content">
			<?php
			if(isset($integrity) && is_string($integrity)) display_errors($integrity);
			?>
<?php afflinkbar($todo,$id, $lang); ?>
			<h2>
			<? echo formatTitleh2($GLOBALS['lang']['workshop']['name']." : ".$workshop_denomination); ?>
			</h2>
			<form id="addtask" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
				<p>
				<label for="task"><? echo $GLOBALS['lang']['workshop']['task']; ?> * : </label>
				<input name="task" type="text" class="textfield" id="task" maxlength="200" value="<?php echo $form_task; ?>" />
				</p>
				<p>
				<label for="task_details"><? echo $GLOBALS['lang']['workshop']['task_details']; ?> * : </label>
				<textarea id="task_details" name="task_details" <?php echo AREA_SETTINGS; ?> class="largetextfield" ><?php echo $form_task_details; ?></textarea>
				</p>
				<p>
				<? echo $GLOBALS['lang']['workshop']['date']; ?> :
				</p>
				<div class="datediv">
				<p class="date">
				<label for="day" class="labeldate" ><?php echo $GLOBALS['lang']['workshop']['day'] ?> * :</label>
                <?php $day=select_date($form_day, "day", "D");
				echo $day; ?>
				</p>
				<p class="date">
				<label for="month" class="labeldate" ><?php echo $GLOBALS['lang']['workshop']['month'] ?> * :</label>
				<?php $month=select_date($form_month, "month", "M");
				echo $month; ?>
				</p>
				<p class="date">
				<label for="year" class="labeldate" ><?php echo $GLOBALS['lang']['workshop']['year'] ?> * :</label>
				<?php $year=select_date($form_year, "year", "Y"); 
				echo $year;
				?>
				</p>
				<br class="brendstep" />
				</div>
				<div>
				<input name="task_id" type="hidden" value="<?php echo $task_id; ?>" id="task_id" />
				<input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
				<? echo cancel_button($link_cancel); ?>
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid'] ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
<?php include_once($dir."/help.php"); ?>
</div>
<?php
// Récapitulatif
} else	{

if(empty($form_task)) $display_form_task=$GLOBALS['lang']['workshop']['recap_nc'];
else $display_form_task=formatText($form_task, $text_format);

if(empty($form_task_details)) $display_form_task_details=$GLOBALS['lang']['workshop']['recap_nc'];
else $display_form_task_details=formatText($form_task_details, $text_format);

$date_timestamp_display;
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
<?php afflinkbar($todo,$id, $lang); ?>
			<h2><? echo $GLOBALS['lang']['recap']['title'] ?></h2>
			<?php
			echo "<dl class=\"dl3\">\n";
			echo "<dt>".$GLOBALS['lang']['workshop']['task']."</dt>\n";
			echo "<dd>". $display_form_task."</dd>\n";
			echo "<dt>". $GLOBALS['lang']['workshop']['task_details']. "</dt>\n";
			echo "<dd>".$display_form_task_details."</dd>\n";
			echo "<dt>".$GLOBALS['lang']['workshop']['date']." :</dt>\n";
			echo "<dd>".$date_timestamp_display."</dd>\n";
			echo "</dl>\n";
			?>
			<form id="addtask" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
				<div>
				<input name="task_id" type="hidden" value="<?php echo $task_id; ?>" id="id" />
				<input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<? echo cancel_button($link_cancel); ?>
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="data_table" type="hidden" value="<?php echo $table; ?>" id="data_table" />
				<input name="retour" type="button" value="<? echo $GLOBALS['lang']['btn']['preview'] ?>" class="button" id="retour" onclick="history.go(-1);" />
				<input name="enregistrer" type="submit" value="<? echo $GLOBALS['lang']['btn']['save'] ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
	<?php include_once($dir."/help.php"); ?>
</div>
<?php
}
?>
